==> haskell-wai-extra-3.0.22.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.22.1
id: wai-extra-3.0.22.1-BoQAUEotBY0EHtz0TJeUNb
key: wai-extra-3.0.22.1-BoQAUEotBY0EHtz0TJeUNb
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: bd2f0928ae226c7dd291bb0482a365a9
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.22.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.22.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wai-extra-3.0.22.1
hs-libraries: HSwai-extra-3.0.22.1-BoQAUEotBY0EHtz0TJeUNb
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
    network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v directory-1.3.1.5
    transformers-0.5.5.0 http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
    text-1.2.3.0 case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-E34bJKRtdy053fl0XbEJw9
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG
    resourcet-1.2.1-DyrMduhw6NcBH9776LSX58
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq containers-0.5.11.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    lifted-base-0.2.3.12-IxSic95oGF4HgssxQ5998f deepseq-1.4.3.0
    streaming-commons-0.2.0.0-bIechSnu5o6EZfRGHwD0n
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73
    iproute-1.7.5-2eODguCAoeA6xqKtQaQS4Z unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw=4dcfd1f19878874b7a3f1edbd12d60e9
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             wai-logger-2.3.2-E34bJKRtdy053fl0XbEJw9=d6e2eef585a908c6c782084e0f5306fd
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             resourcet-1.2.1-DyrMduhw6NcBH9776LSX58=5ef1111b0548768da5656735a567125c
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=f14401e2229f003d6e8153beb939779e
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=e8c1944b7c8b87b6021bfbe6be250d99
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             lifted-base-0.2.3.12-IxSic95oGF4HgssxQ5998f=771af66363956aa9512781aff6390e56
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             streaming-commons-0.2.0.0-bIechSnu5o6EZfRGHwD0n=a4aeb8801beb6c03127be61c907782ee
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73=a6f953f9dda8218f3e00f48fbc968e32
             iproute-1.7.5-2eODguCAoeA6xqKtQaQS4Z=175826e3d27ff5edf1550d58a1670d7f
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.22.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.22.1
id: wai-extra-3.0.22.1-E2Ld0a9Zx9yJ42ojKTsQIg
key: wai-extra-3.0.22.1-E2Ld0a9Zx9yJ42ojKTsQIg
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: b409700ed4183de54f1903c8a52af997
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.22.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-extra-3.0.22.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wai-extra-3.0.22.1
hs-libraries: HSwai-extra-3.0.22.1-E2Ld0a9Zx9yJ42ojKTsQIg
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
    network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v directory-1.3.1.5
    transformers-0.5.5.0 http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
    text-1.2.3.0 case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    wai-logger-2.3.2-E34bJKRtdy053fl0XbEJw9
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG
    resourcet-1.2.1-DyrMduhw6NcBH9776LSX58
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq containers-0.5.11.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    lifted-base-0.2.3.12-IxSic95oGF4HgssxQ5998f deepseq-1.4.3.0
    streaming-commons-0.2.0.0-bIechSnu5o6EZfRGHwD0n
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf
    iproute-1.7.5-2eODguCAoeA6xqKtQaQS4Z unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw=4dcfd1f19878874b7a3f1edbd12d60e9
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             wai-logger-2.3.2-E34bJKRtdy053fl0XbEJw9=d6e2eef585a908c6c782084e0f5306fd
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             resourcet-1.2.1-DyrMduhw6NcBH9776LSX58=5ef1111b0548768da5656735a567125c
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=f14401e2229f003d6e8153beb939779e
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=e8c1944b7c8b87b6021bfbe6be250d99
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             lifted-base-0.2.3.12-IxSic95oGF4HgssxQ5998f=771af66363956aa9512781aff6390e56
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             streaming-commons-0.2.0.0-bIechSnu5o6EZfRGHwD0n=a4aeb8801beb6c03127be61c907782ee
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             iproute-1.7.5-2eODguCAoeA6xqKtQaQS4Z=175826e3d27ff5edf1550d58a1670d7f
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
